@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# star data for A4LD.py (Lunar Distance chart)
+# star data for ld_charts.py (Lunar Distance chart)
 
 #   Copyright (C) 2022  Andrew Bauer
 
@@ -18,126 +18,123 @@
 #   You should have received a copy of the GNU General Public License along
 #   with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-# List of navigational stars with data from Hipparcos, e.g.:
-# http://vizier.u-strasbg.fr/viz-bin/VizieR-5?-source=I/311&-out.all&-out.max=10&HIP==677
-# The format corresponds to an XEphem database file:
-# http://www.clearskyinstitute.com/xephem/help/xephem.html#mozTocId468501
 
-db = """
-Alpheratz,f|S|B9,0:08:23.26|137.46,29:05:25.55|-163.44,2.04,2000,0
-Caph,f|S|F2,0:09:10.69|523.50,59:08:59.21|-179.77,2.36,2000,0
-Algenib,f|S|B2,0:13:14.15|1.98,15:11:00.94|-9.28,2.75,2000,0
-Ankaa,f|S|K0,0:26:17.05|233.05,-42:18:21.55|-356.30,2.55,2000,0
-Schedar,f|S|K0,0:40:30.44|50.88,56:32:14.39|-32.13,2.41,2000,0
-Diphda,f|S|G9,0:43:35.37|232.55,-17:59:11.78|31.99,2.21,2000,0
-Mirach,f|S|M0,1:09:43.92|175.90,35:37:14.01|-112.20,2.17,2000,0
-Achernar,f|S|B3,1:37:42.85|87.00,-57:14:12.31|-38.24,0.42,2000,0
-Sheratan,f|S|A5,1:54:38.41|98.74,20:48:28.91|-110.41,2.64,2000,0
-Almach,f|S|B8,2:03:53.95|42.32,42:19:47.02|-49.30,2.24,2000,0
-Hamal,f|S|K2,2:07:10.41|188.55,23:27:44.70|-148.08,2.17,2000,0
-Polaris,f|S|F7,2:31:49.09|44.48,89:15:50.79|-11.85,2.11,2000,0
-Acamar,f|S|A4,2:58:15.68|-52.89,-40:18:16.85|21.98,2.94,2000,0
-Menkar,f|S|M2,3:02:16.77|-10.41,4:05:23.06|-76.85,2.62,2000,0
-Algol,f|S|B8,3:08:10.13|2.99,40:57:20.33|-1.66,2.10,2000,0
-Mirfak,f|S|F5,3:24:19.37|23.75,49:51:40.25|-26.23,1.90,2000,0
-Electra,f|S|B6,3:44:52.54|20.84,24:06:48.01|-46.06,3.69,2000,0
-Taygeta,f|S|B6,3:45:12.50|21.24,24:28:02.21|-40.56,4.27,2000,0
-Maia,f|S|B8,3:45:49.61|20.95,24:22:03.89|-45.98,3.86,2000,0
-Merope,f|S|B6,3:46:19.57|21.13,23:56:54.08|-43.65,4.15,2000,0
-Alcyone,f|S|B7,3:47:29.08|19.34,24:06:18.49|-43.67,2.85,2000,0
-Atlas,f|S|B8,3:49:09.74|17.70,24:03:12.30|-44.18,3.61,2000,0
-Zaurak,f|S|M1,3:58:01.77|60.57,-13:30:30.67|-113.11,3.07,2000,0
-Aldebaran,f|S|K5,4:35:55.24|63.45,16:30:33.49|-188.94,1.00,2000,0
-Rigel,f|S|B8,5:14:32.27|1.31,-8:12:05.90|0.50,0.19,2000,0
-Capella,f|S|M1,5:16:41.36|75.25,45:59:52.77|-426.89,0.24,2000,0
-Bellatrix,f|S|B2,5:25:07.86|-8.11,6:20:58.93|-12.88,1.55,2000,0
-Elnath,f|S|B7,5:26:17.51|22.76,28:36:26.83|-173.58,1.62,2000,0
-Nihal,f|S|G5,5:28:14.72|-5.02,-20:45:33.99|-86.01,2.97,2000,0
-Mintaka,f|S|O9,5:32:00.40|0.64,-0:17:56.74|-0.69,2.14,2000,0
-Arneb,f|S|F0,5:32:43.82|3.56,-17:49:20.24|1.18,2.64,2000,0
-Alnilam,f|S|B0,5:36:12.81|1.44,-1:12:06.91|-0.78,1.62,2000,0
-Alnitak,f|S|O9,5:40:45.53|3.19,-1:56:33.26|2.03,1.68,2000,0
-Saiph,f|S|B0,5:47:45.39|1.46,-9:40:10.58|-1.28,2.01,2000,0
-Betelgeuse,f|S|M2,5:55:10.31|27.54,7:24:25.43|11.30,0.50,2000,0
-Menkalinan,f|S|A2,5:59:31.72|-56.44,44:56:50.76|-0.95,1.90,2000,0
-Mirzam,f|S|B1,6:22:41.99|-3.23,-17:57:21.31|-0.78,1.89,2000,0
-Canopus,f|S|F0,6:23:57.11|19.93,-52:41:44.38|23.24,-0.55,2000,0
-Alhena,f|S|A0,6:37:42.71|13.81,16:23:57.41|-54.96,1.93,2000,0
-Sirius,f|S|A0,6:45:08.92|-546.01,-16:42:58.02|-1223.07,-1.09,2000,0
-Adhara,f|S|B2,6:58:37.55|3.24,-28:58:19.51|1.33,1.42,2000,0
-Wezen,f|S|F8,7:08:23.48|-3.12,-26:23:35.52|3.31,1.96,2000,0
-Castor,f|S|A2,7:34:35.87|-191.45,31:53:17.82|-145.19,1.58,2000,0
-Procyon,f|S|F5,7:39:18.12|-714.59,5:13:29.96|-1036.80,0.46,2000,0
-Pollux,f|S|K0,7:45:18.95|-626.55,28:01:34.32|-45.80,1.29,2000,0
-Naos,f|S|O5,8:03:35.05|-29.71,-40:00:11.33|16.68,2.14,2000,0
-Avior,f|S|K3,8:22:30.84|-25.52,-59:30:34.14|22.06,2.00,2000,0
-Suhail,f|S|K4,9:07:59.76|-24.01,-43:25:57.33|13.52,2.34,2000,0
-Miaplacidus,f|S|A2,9:13:11.98|-156.47,-69:43:01.95|108.95,1.66,2000,0
-Alphard,f|S|K3,9:27:35.24|-15.23,-8:39:30.96|34.37,2.14,2000,0
-Regulus,f|S|B7,10:08:22.31|-248.73,11:58:01.95|5.59,1.32,2000,0
-Algieba,f|S|K0,10:19:58.35|304.30,19:50:29.35|-154.28,2.17,2000,0
-Merak,f|S|A1,11:01:50.48|81.43,56:22:56.73|33.49,2.35,2000,0
-Dubhe,f|S|F7,11:03:43.67|-134.11,61:45:03.72|-34.70,1.95,2000,0
-HIP55203,f|S|G0,11:18:10.90|0.0,31:31:45.00|0.0,3.79,2000,0
-Denebola,f|S|A3,11:49:03.58|-497.68,14:34:19.41|-114.67,2.16,2000,0
-Phecda,f|S|A0,11:53:49.85|107.68,53:41:41.14|11.01,2.43,2000,0
-Minkar,f|S|K2,12:10:07.48|-71.74,-22:37:11.16|10.25,3.18,2000,0
-Megrez,f|S|A3,12:15:25.56|104.11,57:01:57.42|7.30,3.34,2000,0
-Gienah,f|S|B8,12:15:48.37|-158.61,-17:32:30.95|21.86,2.55,2000,0
-Acrux,f|S|B0,12:26:35.90|-35.83,-63:05:56.73|-14.86,0.67,2000,0
-Gacrux,f|S|M4,12:31:09.96|28.23,-57:06:47.57|-265.08,1.63,2000,0
-Mimosa,f|S|B0,12:47:43.27|-42.97,-59:41:19.58|-16.18,1.15,2000,0
-Alioth,f|S|A0,12:54:01.75|111.91,55:57:35.36|-8.24,1.75,2000,0
-Vindemiatrix,f|S|G8,13:02:10.60|-273.80,10:57:32.94|19.96,3.00,2000,0
-Mizar,f|S|A2,13:23:55.54|119.01,54:55:31.27|-25.97,2.25,2000,0
-Spica,f|S|B1,13:25:11.58|-42.35,-11:09:40.75|-30.67,0.89,2000,0
-Alcor,f|S|A5,13:25:13.54|120.21,54:59:16.65|-16.04,4.05,2000,0
-Alkaid,f|S|B3,13:47:32.44|-121.17,49:18:47.76|-14.91,1.80,2000,0
-Hadar,f|S|B1,14:03:49.41|-33.27,-60:22:22.93|-23.16,0.54,2000,0
-Thuban,f|S|A0,14:04:23.35|-56.34,64:22:33.06|17.21,3.65,2000,0
-Menkent,f|S|K0,14:06:40.95|-520.53,-36:22:11.84|-518.06,2.22,2000,0
-Arcturus,f|S|K2,14:15:39.67|-1093.39,19:10:56.67|-2000.06,0.11,2000,0
-Rigil Kent.,f|S|G2,14:39:36.49|-3679.25,-60:50:02.37|473.67,0.14,2000,0
-Izar,f|S|A0,14:44:59.22|-50.95,27:04:27.21|21.07,2.52,2000,0
-Kochab,f|S|K4,14:50:42.33|-32.61,74:09:19.81|11.42,2.20,2000,0
-Zuben'ubi,f|S|A3,14:50:52.71|-105.68,-16:02:30.40|-68.40,2.79,2000,0
-Alphecca,f|S|A0,15:34:41.27|120.27,26:42:52.89|-89.58,2.22,2000,0
-Unukalhai,f|S|K2,15:44:16.07|133.84,6:25:32.26|44.81,2.80,2000,0
-HIP78727,f|S|F5,16:04:21.63|-60.0,-11:22:24.8|-29.0,4.16,2000,0
-Athebyne,f|S|G8,16:23:59.49|-17.02,61:30:51.17|56.95,2.73,2000,0
-Antares,f|S|M1,16:29:24.46|-12.11,-26:25:55.21|-23.30,0.98,2000,0
-Atria,f|S|K2,16:48:39.90|17.99,-69:01:39.76|-31.58,2.07,2000,0
-Sabik,f|S|A2,17:10:22.69|40.13,-15:43:29.66|99.17,2.44,2000,0
-Rasalgethi,f|S|M5,17:14:38.86|-7.32,14:23:25.23|36.07,2.91,2000,0
-Shaula,f|S|B1,17:33:36.52|-8.53,-37:06:13.76|-30.80,1.52,2000,0
-Rasalhague,f|S|A5,17:34:56.07|108.07,12:33:36.13|-221.57,2.13,2000,0
-Cebalrai,f|S|K2,17:43:28.35|-41.45,4:34:02.30|159.34,2.93,2000,0
-Eltanin,f|S|K5,17:56:36.37|-8.48,51:29:20.02|-22.79,2.36,2000,0
-Kaus Aust.,f|S|B9,18:24:10.32|-39.42,-34:23:04.62|-124.20,1.80,2000,0
-Vega,f|S|A0,18:36:56.34|200.94,38:47:01.28|286.23,0.09,2000,0
-Sheliak,f|S|A8,18:50:04.80|1.90,33:21:45.61|-3.53,3.56,2000,0
-Nunki,f|S|B2,18:55:15.93|15.14,-26:17:48.21|-53.43,2.01,2000,0
-Sulafat,f|S|B9,18:58:56.62|-3.09,32:41:22.40|1.11,3.23,2000,0
-Arkab Prior,f|S|B9,19:22:38.30|13.67,-44:27:32.25|-19.03,3.94,2000,0
-Arkab Posterior,f|S|F2,19:23:13.14|93.45,-44:47:59.21|-54.09,4.35,2000,0
-Rukbat,f|S|B8,19:23:53.17|30.49,-40:36:57.37|-119.21,3.93,2000,0
-Albireo,f|S|K3,19:30:43.28|-7.17,27:57:34.85|-6.15,3.22,2000,0
-Tarazed,f|S|K3,19:46:15.58|16.99,10:36:47.74|-2.98,2.87,2000,0
-Altair,f|S|A7,19:50:47.00|536.23,8:52:05.96|385.29,0.83,2000,0
-Alshain,f|S|G8,19:55:18.79|45.27,6:24:24.34|-481.91,3.87,2000,0
-Sadr,f|S|F8,20:22:13.70|2.39,40:15:24.04|-0.91,2.35,2000,0
-Peacock,f|S|B2,20:25:38.86|6.90,-56:44:06.32|-86.02,1.86,2000,0
-Deneb,f|S|A2,20:41:25.92|2.01,45:16:49.22|1.85,1.30,2000,0
-Alderamin,f|S|A7,21:18:34.77|150.55,62:35:08.07|49.09,2.51,2000,0
-Alfirk,f|S|B2,21:28:39.60|12.54,70:33:38.57|8.39,3.14,2000,0
-Sadalsuud,f|S|G0,21:31:33.53|18.77,-5:34:16.23|-8.21,2.90,2000,0
-Enif,f|S|K2,21:44:11.16|26.92,9:52:30.03|0.44,2.55,2000,0
-Deneb Algedi,f|S|A5,21:47:02.44|261.70,-16:07:38.23|-296.70,2.85,2000,0
-Sadalmelik,f|S|G2,22:05:47.04|18.25,-0:19:11.46|-9.39,3.11,2000,0
-Al Na'ir,f|S|B7,22:08:13.98|126.69,-46:57:39.51|-147.47,1.70,2000,0
-Fomalhaut,f|S|A3,22:57:39.05|328.95,-29:37:20.05|-164.67,1.18,2000,0
-Scheat,f|S|M2,23:03:46.46|187.65,28:04:58.03|136.93,2.49,2000,0
-Markab,f|S|B9,23:04:45.65|60.40,15:12:18.96|-41.30,2.48,2000,0
+# list of popular stars (Hipparcos #, Name)
+popstars = """
+   677 Alpheratz
+   746 Caph
+  1067 Algenib
+  2081 Ankaa
+  3179 Schedar
+  3419 Diphda
+  5447 Mirach
+  7588 Achernar
+  8903 Sheratan
+  9640 Almach
+  9884 Hamal
+ 11767 Polaris
+ 13847 Acamar
+ 14135 Menkar
+ 14576 Algol
+ 15863 Mirfak
+ 17499 Electra
+ 17531 Taygeta
+ 17573 Maia
+ 17608 Merope
+ 17702 Alcyone
+ 17847 Atlas
+ 18543 Zaurak
+ 21421 Aldebaran
+ 24436 Rigel
+ 24608 Capella
+ 25336 Bellatrix
+ 25428 Elnath
+ 25606 Nihal
+ 25930 Mintaka
+ 25985 Arneb
+ 26311 Alnilam
+ 26727 Alnitak
+ 27366 Saiph
+ 27989 Betelgeuse
+ 28360 Menkalinan
+ 30324 Mirzam
+ 30438 Canopus
+ 31681 Alhena
+ 32349 Sirius
+ 33579 Adhara
+ 34444 Wezen
+ 36850 Castor
+ 37279 Procyon
+ 37826 Pollux
+ 39429 Naos
+ 41037 Avior
+ 44816 Suhail
+ 45238 Miaplacidus
+ 46390 Alphard
+ 49669 Regulus
+ 50583 Algieba
+ 53910 Merak
+ 54061 Dubhe
+ 55203 HIP55203
+ 57632 Denebola
+ 58001 Phecda
+ 59316 Minkar
+ 59774 Megrez
+ 59803 Gienah
+ 60718 Acrux
+ 61084 Gacrux
+ 62434 Mimosa
+ 62956 Alioth
+ 63608 Vindemiatrix
+ 65378 Mizar
+ 65474 Spica
+ 65477 Alcor
+ 67301 Alkaid
+ 68702 Hadar
+ 68756 Thuban
+ 68933 Menkent
+ 69673 Arcturus
+ 71683 Rigil Kent.
+ 72105 Izar
+ 72607 Kochab
+ 72622 Zuben'ubi
+ 76267 Alphecca
+ 77070 Unukalhai
+ 78727 HIP78727
+ 80331 Athebyne
+ 80763 Antares
+ 82273 Atria
+ 84012 Sabik
+ 84345 Rasalgethi
+ 85927 Shaula
+ 86032 Rasalhague
+ 86742 Cebalrai
+ 87833 Eltanin
+ 90185 Kaus Aust.
+ 91262 Vega
+ 92420 Sheliak
+ 92855 Nunki
+ 93194 Sulafat
+ 95241 Arkab Prior
+ 95294 Arkab Posterior
+ 95347 Rukbat
+ 95947 Albireo
+ 97278 Tarazed
+ 97649 Altair
+ 98036 Alshain
+100453 Sadr
+100751 Peacock
+102098 Deneb
+105199 Alderamin
+106032 Alfirk
+106278 Sadalsuud
+107315 Enif
+107556 Deneb Algedi
+109074 Sadalmelik
+109268 Al Na'ir
+113368 Fomalhaut
+113881 Scheat
+113963 Markab
 """
 
 # List of navigational stars with magnitude <= 1.5 (with Hipparcos Catalog Number) plus Polaris
